@@ -37,29 +37,30 @@ async def compute_flow(graph):
             )
             logger.debug("Input received")
             aio.raise_task_exceptions(completed_tasks)
-            completed_coro_functions = [
+            completed_repeater_functions = [
                 task.aio_coroutine_function
                 for task in completed_tasks
                 if is_repeater(task.aio_coroutine_function)
             ]
             callables, new_tasks = aio.prepare_ready_set(
-                completed_coro_functions
+                completed_repeater_functions
             )
             assert len(callables) == 0
             running_tasks |= new_tasks
+            logger.debug("Computing dependent nodes")
             for node in graph.topological_ordering:
-                logger.debug("Computing dependent nodes")
                 if node in input_nodes:
                     continue
+                logger.debug("Computing dependent node: %s", node)
                 if inspect.iscoroutinefunction(node):
                     await node()
                 else:
                     assert callable(node)
                     node()
     except asyncio.CancelledError as e:
-        aio.cancel_tasks(running_tasks)
+        await aio.cancel_tasks(running_tasks)
         raise
     except Exception as e:
-        aio.cancel_tasks(running_tasks)
+        await aio.cancel_tasks(running_tasks)
         logger.exception("compute_flow error")
         raise
